@@ -71,25 +71,23 @@ _previous_executed_sql = ""
 has_passed_variables = False
 passed_variables = {}
 
-def configure_log():
-    """Configures the logging that will be performed for any data related execution on the snowflake connection.
-    The log file is named 'snowflake_python_connector.log'
-    """
-    logging.basicConfig(
-        filename= 'snowflake_python_connector.log',
-        level=logging.DEBUG,
-        format="{asctime} {levelname:<8} {message}",
-        style="{",
-        filemode='w')
-
 def configure_log(configuration_path):
     """Configures the logging that will be performed for any data related execution on the snowflake connection.
+        The log file is named 'snowflake_python_connector.log' by default.
 
         configuration_path
             The configuration path of the file that contains all the settings desired for the logging.
-
     """
-    logging.config.fileConfig(configuration_path)
+    if configure_log : 
+        logging.config.fileConfig(configuration_path)
+    else :
+        logging.basicConfig(
+            filename= 'snowflake_python_connector.log',
+            level=logging.DEBUG,
+            format="{asctime} {levelname:<8} {message}",
+            style="{",
+            filemode='w')
+
 
 def log(*msg, level=logging.INFO, writter=None):
     """ Prints a message to the console (standard output) or to the log file, depending on if logging is enabled.
@@ -98,23 +96,17 @@ def log(*msg, level=logging.INFO, writter=None):
             The message to print or log.
     """
     if snow_logging_enabled :
-        finalmsg = ""
-        for item in msg :
-            finalmsg += re.sub('\033\[\d*m','', str(item))
+        finalmsg = [re.sub('\033\[\d*m','', str(item)) for item in msg]
         if level == logging.ERROR :
-            logging.error(finalmsg)
+            logging.error(*finalmsg)
         elif level == logging.DEBUG:
-            logging.debug(finalmsg)
+            logging.debug(*finalmsg)
         elif level == logging.WARNING:
-            logging.warning(finalmsg)
+            logging.warning(*finalmsg)
         else:
-            logging.info(finalmsg)
-
+            logging.info(*finalmsg)
     else :
-        finalmsg = ""
-        for item in msg :
-            finalmsg += str(item)
-        print(finalmsg, file=writter)
+        print(*msg, file=writter)
 
 def get_from_vars_or_args_or_environment(arg_pos, variable_name, vars, args):
     """Gets the argument from the position specified or gets the value from the table vars or gets the environment variable name passed.
@@ -256,6 +248,8 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
         login_timeout
             The maximum timeout before giving error if the connection is taking too
             long to connect
+        authenticator
+            The authenticator to use.
     """
     global error_code
     global opened_connections
@@ -280,21 +274,28 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
     if query_tag is None:
         frm = inspect.stack()[1]
         query_tag = path.basename(frm.filename)
+    authenticator = getenv("SNOW_AUTHENTICATOR", None)
     c = None
     try:
-        c = snowflake.connector.connect(
-            user=user,
-            password=password,
-            account=account,
-            database=database,
-            warehouse=warehouse,
-            application=COMPANY_NAME,
-            role=role,
-            login_timeout=login_timeout,
-            session_parameters={
-                'QUERY_TAG': query_tag
+
+        p = {
+                'user' : user,
+                'password' : password,
+                'account' :account,
+                'database' :database,
+                'warehouse' :warehouse,
+                'application' : COMPANY_NAME,
+                'role' : role,
+                'login_timeout' : login_timeout,
+                'session_parameters' : {
+                    'QUERY_TAG': query_tag
+                }
             }
-        )
+
+        if authenticator :
+            p ["authenticator"] = authenticator
+            
+        c = snowflake.connector.connect(**p)
     except Exception as e:
         log(f"{colored('*** Failure: logon failed :', 'red')} { str(e) }", level = logging.ERROR, writter = sys.stderr)
         error_code = 333
